<?php
/**
 * Emercury for WP
 *
 * @package Emercury_WP_Integration
 *
 *
 * Plugin Name: Emercury for WP
 * Plugin URI: https://www.emercury.net/resources/Apps-Integrations/Wordpress-Emercury-Forms-Plugin/3/
 * Description: Allow your visitors to subscribe to your forms seamlessly with this plugin.
 * Author: Emercury
 * Author URI: https://www.emercury.net
 * Version: 1.0.4
 *
 * Copyright (c) 2020 Emercury
 *
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * @author    Emercury
 * @copyright Copyright (c) 2020 Emercury
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GNU General Public License v3.0.
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once plugin_dir_path(__FILE__) . 'includes/functions.php';
require_once plugin_dir_path(__FILE__) . 'includes/emercury.php';
require_once plugin_dir_path(__FILE__) . 'includes/emercury_forms_widget.php';
require_once plugin_dir_path(__FILE__) . 'includes/emercury_forms_advanced_options.php';


if ( ! class_exists( 'Emercury_WP_Integration' ) ) {

	class Emercury_WP_Integration {

		const TABLE_EMERCURY_FORMS = "emercury_forms";
		
		/**
		 * @var Singleton The reference the *Singleton* instance of this class
		 */
		private static $instance;

		private $plugin_base_url;
		public static $table_emercury;
		public $_wpdb;

		/**
		 * Returns the *Singleton* instance of this class.
		 *
		 * @return Singleton The *Singleton* instance.
		 */
		public static function get_instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		public function __construct() {

			global $wpdb;
			$this->_wpdb = $wpdb;
			self::$table_emercury = $this->_wpdb->prefix . self::TABLE_EMERCURY_FORMS;
			$this->plugin_base_url = plugins_url('/', __FILE__ );
			add_action( 'plugins_loaded', array( $this, 'init' ) );
		}

		public function init() {
			add_action( 'admin_init', array( $this, 'admin_enqueue_scripts' ) );
			add_action( 'admin_menu', array( $this, 'register_emercury_forms_admin_page'), 20 );
			add_filter( 'plugin_action_links', array( $this, 'plugin_emercury_forms_action_links'), 10, 2 );
			add_shortcode( 'emercury_forms', array( $this, 'emercury_forms_handler') );
			add_filter( 'http_request_timeout', array( $this, 'wp_emercury_timeout_extend') );
			add_action( 'widgets_init', array( $this, 'register_Emercury_Forms_Widget') );
			if (isset($_GET['page']) && in_array($_GET['page'], array('emercury-forms.php', 'emercury_forms_advanced_options', 'emercury_forms_settings'))) {
		        add_action('in_admin_header', array($this, 'printAdminPageHeader'));
		    }
		}

		/**
		 * Register Emercury_Forms_Widget
		 */
		public function register_Emercury_Forms_Widget() {
			register_widget( 'Emercury_Forms_Widget' );
		}

		/**
		 * Registers Js
		 */
		public function admin_enqueue_scripts() {
			$plugin_data = get_plugin_data( __FILE__, false, false );
			$plugin_version = $plugin_data[ 'Version' ];
			wp_enqueue_script('emercury-form-js', $this->plugin_base_url . 'assets/js/emercury-form.js', array(), $plugin_version, true);
		}

		public function register_emercury_forms_admin_page() {

		    add_menu_page( 'Emercury Forms', 'Emercury Forms', 'manage_options', 'emercury-forms.php', array($this, 'printAdminPageForm'), $this->plugin_base_url . 'images/icon.png', 6 );

		    // Create Emercury Forms.
        	add_submenu_page('emercury-forms.php', 'Forms', 'Forms', 'manage_options', 'emercury-forms.php', array($this, 'printAdminPageForm'));

        	// Advanced Options.
        	add_submenu_page('emercury-forms.php', 'Advanced Options', 'Advanced Options', 'manage_options', 'emercury_forms_advanced_options', array($this, 'printAdminPageAdvancedOptions'));

        	// Create Emercury Forms Settings.
        	add_submenu_page('emercury-forms.php', 'Settings', 'Settings', 'manage_options', 'emercury_forms_settings', array($this, 'printAdminPageSettings'));
		}

		public function printAdminPageHeader() {
	        include(dirname(__FILE__) . '/php/emercury_wp_admin_header.php');
	    }

	    public function printAdminPageAdvancedOptions() {
	        include(dirname(__FILE__) . '/php/emercury_forms_admin_advanced_options.php');
	    }

		public function printAdminPageSettings() {
	        include(dirname(__FILE__) . '/php/emercury_forms_admin_settings.php');
	    }

	    public function printAdminPageForm() {
	        include(dirname(__FILE__) . '/php/emercury_forms_admin.php');
	    }

		/**
		 * Add Settings Link
		 */
		public function plugin_emercury_forms_action_links( $actions, $plugin_file ){
			if( false === strpos( $plugin_file, basename(__FILE__) ) )
				return $actions;

			$settings_link = '<a href="admin.php?page=emercury_forms_settings' .'">Settings</a>';
			array_unshift( $actions, $settings_link ); 
			return $actions; 
		}

		/**
		 * Request Timeout
		 */
		public function wp_emercury_timeout_extend( $time )
		{
		    return 15;
		}

		//create table
		static function activate_emercury_forms() {
		
		    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

			$charset_collate = "DEFAULT CHARACTER SET {$wpdb->charset} COLLATE {$wpdb->collate}";

			$table_emercury = self::$table_emercury;
			$sql_emercury = "CREATE TABLE IF NOT EXISTS {$table_emercury} (
			    id int(11) unsigned NOT NULL AUTO_INCREMENT,
				form_id int(11) unsigned NOT NULL,
				name varchar(255) NOT NULL,
				code text NOT NULL,
				PRIMARY KEY (id)
			) {$charset_collate};";

			dbDelta( $sql_emercury );
		}

		public function emercury_forms_handler($atts) {
			
			$emercury_forms_tbl = self::$table_emercury;
			if (isset($atts['id']) && !empty($atts['id']) && (int) $atts['id'] > 0) {
			
				$form_id = (int) $atts['id'];
				$form = $this->_wpdb->get_results( "SELECT code FROM $emercury_forms_tbl WHERE form_id = $form_id" );
				if (isset($form[0]->code) && !empty($form[0]->code)) {
					return $form[0]->code;
				}
			} 
			return '';
		}

	}

	if ( ! defined( 'WC_UNIT_TESTING' ) ) {
		Emercury_WP_Integration::get_instance();
	}
}

register_activation_hook( __FILE__, array( 'Emercury_WP_Integration', 'activate_emercury_forms' )  );

/**
 * Emercury_Forms_Advanced_Options
 */
if (get_option('emercury_form_add_subscriber_comment') == 1 && is_numeric(get_option('emercury_form_select_list_subscriber_comment') ) )
{
    add_action('comment_post', array('Emercury_Forms_Advanced_Options', 'send_comment_from_post'));
    add_action('comment_unapproved_to_approved', array('Emercury_Forms_Advanced_Options', 'comment_approved'));
}

if (get_option('emercury_form_add_subscriber_signup') == 1 && is_numeric(get_option('emercury_form_select_list_subscriber_signup') ) )
{
    add_action('user_register', array('Emercury_Forms_Advanced_Options', 'grab_subscriber_from_registration'));
}
