<?php

if ( ! class_exists( 'Emercury_API' ) ) {

class Emercury_API {

    const API_URL = 'https://panel.emercury.net/wp/';
    const API_URL_XML = 'https://panel.emercury.net/api.php';
    const API_ERROR = 'You need to set API key';

    private static function getApiEmail()
    {
        return get_option('emercury_form_email');
    }

    private static function getApiKey()
    {
        return get_option('emercury_forms_sec_id');
    }

    static function getAudience()
    {
        $result = self::checkApiParameters();

        $xml = '<?xml version="1.0" encoding="utf-8"?>
            <request>
                <method>GetAudiences</method>
                <user mail="'. self::getApiEmail() .'" API_key="'. self::getApiKey() .'"></user>
            </request>';

        $result = self::sendRequestXML($xml );

        return $result;
    }

    static function updateSubscribers($data, $list_id)
    {
        $result = '';
        foreach ($data as $key => $value) {
            $result .= "<". $key .">". $value ."</". $key .">";
        }

        $xml = '<?xml version="1.0" encoding="utf-8" ?>
                    <request>
                        <method>UpdateSubscribers</method>
                        <user mail="'. self::getApiEmail() .'" API_key="'. self::getApiKey() .'"></user>
                        <parameters>
                            <audience_id>'. $list_id .'</audience_id>
                            <date_format_id>1</date_format_id>
                            <subscriber>
                                '.$result.'
                            </subscriber>

                        </parameters>
                    </request>';  
    
        return self::sendRequestXML($xml );
    }

    static function getEmercuryForms()
    {
        $postdata = array(
            'func'  => 'get_forms',
            'email' => self::getApiEmail(),
            'emercury_forms_sec_id' => self::getApiKey()
        );

        $result = self::checkApiParameters();
        if(isset($result['class']) && $result['class'] == 'error'){
            echo json_encode($result);
            wp_die();
        }

        $result = self::sendRequest($postdata );

        if($result['code'] == 'ok') {
            $result = $result['message'];
        } else {
            $result = '';
            $message = json_encode($result['message']);
        }
         
        $class = 'error';
    
        if (isset($result) && isset($result->success)) {
    
            if (isset($result->msg) && !empty($result->msg)) {
            
                $message = $result->msg;
            }
        
            if ($result->success) {
            
                if (!isset($result->data) || empty($result->data) || count($result->data) < 1) {
                
                    $message = 'Missing Emercury Forms Data.';
                    
                } else {
                    
                    $emercury_forms = new Emercury_WP_Integration();
                    $emercury_forms_tbl = Emercury_WP_Integration::$table_emercury;

                    $message = $result->msg;
                    
                    $up  = 0;
                    $ins = 0;
                    $f_ids = array();
                    
                    foreach ($result->data as $form) {
                    
                        $f_ids[] = $form->id;
                    
                        $isset_form = $emercury_forms->_wpdb->get_results("SELECT form_id FROM $emercury_forms_tbl WHERE form_id = " . $form->id);
                        
                        $query_data = array(
                            'form_id' => $form->id,
                            'name' => $form->name,
                            'code' => $form->code
                        );

                        if (count($isset_form)) {

                            $emercury_forms->_wpdb->update( 
                                $emercury_forms_tbl,
                                $query_data,
                                array( 'form_id' => $form->id ),
                                array( '%d', '%s', '%s' ),
                                array( '%d' )
                            );
                        
                            $up++;
                        
                        } else {
                        
                            $emercury_forms->_wpdb->insert(  
                                $emercury_forms_tbl,
                                $query_data,
                                array( '%d', '%s', '%s' )
                            );
                        
                            $ins++;
                        
                        }
                    
                    }
                    
                    if (count($f_ids)) {
                        $emercury_forms->_wpdb->query("DELETE FROM $emercury_forms_tbl WHERE form_id NOT IN (".implode(',', $f_ids).")");
                    }
                    
                    if ($up == 0 && $ins == 0) {
                    
                        $message = 'Can\'t update form(s) data.';
                        
                    } elseif ($up > 0 && $ins > 0) {
                        
                        $message = 'Form(s) has been added and updated successfully.';
                        $class = 'updated';
                        
                    } elseif ($up > 0) {
                    
                        $message = 'Form(s) has been updated successfully.';
                        $class = 'updated';
                        
                    } elseif ($ins > 0) {
                    
                        $message = 'Form(s) has been added successfully.';
                        $class = 'updated';
                    }
                }
            }
        }

        return array(
            'message' => $message ,
            'class' => $class
        );
    }

    static function updateEmercuryForms($form_id, $emercury_forms_sec_id )
    {
        $postdata = array(
            'func'  => 'get_form',
            'form_id' => $form_id,
            'emercury_forms_sec_id' => $emercury_forms_sec_id
        );

        $result = self::sendRequest($postdata );

        if($result['code'] == 'ok') {
            $result = $result['message'];
        } else {
            $result = '';
            $message = json_encode($result['message']);
        }
         
        $class = 'error';

        if (isset($result) && isset($result->success)) {
    
            if (isset($result->msg) && !empty($result->msg)) {
            
                $message = $result->msg;
            }
        
            if ($result->success) {
            
                if (!isset($result->data) || empty($result->data) || count($result->data) < 1) {
                
                    $message = 'Missing Emercury Form Data.';
                    
                } else {

                    $emercury_forms = new Emercury_WP_Integration();
                    $emercury_forms_tbl = Emercury_WP_Integration::$table_emercury;
                
                    $message = $result->msg;
                    
                    $up  = 0;
                    
                    foreach ($result->data as $form) {
                    
                        $isset_form = $emercury_forms->_wpdb->get_results("SELECT form_id FROM $emercury_forms_tbl WHERE form_id = " . $form->id);
                        
                        $query_data = array(
                            'form_id' => $form->id,
                            'name' => $form->name,
                            'code' => $form->code
                        );

                        if (count($isset_form)) {

                            $emercury_forms->_wpdb->update( 
                                $emercury_forms_tbl,
                                $query_data,
                                array( 'form_id' => $form->id ),
                                array( '%d', '%s', '%s' ),
                                array( '%d' )
                            );
                            
                            $up++;
                        
                        }
                    
                    }
                    
                    if ($up == 0) {
                    
                        $message = 'Error in form updating precess.';
                        
                    } else {
                    
                        $message = 'Form has been updated successfully.';
                        $class = 'updated';           
                    }
                }
            }
        }
        
        return array(
            'message' => $message ,
            'class' => $class
        );
    }

    private static function parameters($request)
    {
        return array(
            'method' => 'POST',
            'httpversion' => '1.0',
            'blocking' => true,
            'sslverify' => false,
            'body' => $request
        ); 
    }

    private static function parametersXML($request)
    {
        $body = [];
        $body['request'] = $request;

        return array(
            'method' => 'POST',
            'httpversion' => '1.0',
            'blocking' => true,
            'sslverify' => false,
            'body' => $body
        ); 
    }

    private static function checkApiParameters()
    {
        if (self::getApiKey() === '' || self::getApiEmail() === '') {
            return array(
                'message' => 'Fill in please <strong>Emercury Email* and API Key*</strong> on the Settings page!',
                'class' => 'error'
            );
        }
        return null;
    }

    /**
    * @return array
    */
    private static function sendRequest($postdata )
    {
        $res = wp_remote_request(self::API_URL, 
            self::parameters($postdata)
        );

        $output = [];
        if (is_wp_error( $res ) ) {
            $output = [
                'code' => 'error',
                'message' => $res->get_error_message()
            ]; 
        } else {
            $res = $res['body'];
            $output = [
                'code' => 'ok',
                'message' => (is_string($res)) ? json_decode($res) : $res 
            ];
        }
        return $output;
    }

    /**
    * @return array
    */
    private static function sendRequestXML($xml )
    {
        $res = wp_remote_request(self::API_URL_XML, 
            self::parametersXML($xml)
        );

        $output = [];
        if (is_wp_error( $res ) ) {
            $output = [
                'code' => 'error',
                'message' => $res->get_error_message()
            ]; 
        } else {
            $res = $res['body'];
            $output = [
                'code' => 'ok',
                'message' => (is_string($res)) ? simplexml_load_string($res) : $res 
            ];
        }
        return $output;
    }
}

}
