<?php

add_action('wp_ajax_emercury_form_get_update', 'emercury_form_get_update_callback');
add_action('wp_ajax_nopriv_emercury_form_get_update', 'emercury_form_get_update_callback');
function emercury_form_get_update_callback(){

    $message = '';
    $class = '';

    if (isset($_POST['email']) && isset($_POST['emercury_forms_sec_id'])) {
        
        $email = sanitize_text_field($_POST['email']);
        $emercury_forms_sec_id = sanitize_text_field($_POST['emercury_forms_sec_id']);
        
        if (empty($email) || empty($emercury_forms_sec_id)) {

            update_option('emercury_form_email', '');
            update_option('emercury_forms_sec_id', '');
            $message = 'Please fill in all <strong>required fields *</strong>';
            $class = 'error';
        
        } else {
            update_option('emercury_form_email', $email);
            update_option('emercury_forms_sec_id', $emercury_forms_sec_id);
            $result = Emercury_API::getEmercuryForms();
        }

    } else {
        $result = Emercury_API::getEmercuryForms();
    }

    echo json_encode(array(
        'message' => $message ? $message : $result['message'],
        'class' => $class ? $class : $result['class']
    ));

    wp_die();
}

add_action('wp_ajax_emercury_form_update_single', 'emercury_form_update_single_callback');
add_action('wp_ajax_nopriv_emercury_form_update_single', 'emercury_form_update_single_callback');
function emercury_form_update_single_callback() {

    $message = '';
    $class = '';

    if (isset($_POST['form_id']) && isset($_POST['emercury_forms_sec_id'])) {
        
        $form_id = sanitize_text_field($_POST['form_id']);
        $emercury_forms_sec_id = sanitize_text_field($_POST['emercury_forms_sec_id']);
        
        if (empty($form_id) || empty($emercury_forms_sec_id)) {
        
            $message = 'Wrong Form ID or API Key.';
            $class = 'error';
        
        } else {
            $result = Emercury_API::updateEmercuryForms($form_id, $emercury_forms_sec_id );
        }
    }

    echo json_encode(array(
        'message' => $message ? $message : $result['message'],
        'class' => $class ? $class : $result['class']
    ));

    wp_die();
}

add_action('wp_ajax_emercury_forms_advanced_options', 'emercury_forms_advanced_options_callback');
add_action('wp_ajax_nopriv_emercury_forms_advanced_options', 'emercury_forms_advanced_options_callback');
function emercury_forms_advanced_options_callback() {

    $message_comment = '';
    $class_comment = '';
    $message_signup = '';
    $class_signup = '';

    $checkbox_comment = sanitize_text_field($_POST['emercury_form_add_subscriber_comment']);
    $select_list_comment = sanitize_text_field($_POST['emercury_form_select_list_subscriber_comment']);

    $checkbox_signup = sanitize_text_field($_POST['emercury_form_add_subscriber_signup']);
    $select_list_signup = sanitize_text_field($_POST['emercury_form_select_list_subscriber_signup']);
    
    if (empty($checkbox_comment) || empty($select_list_comment) ) {
        
        update_option('emercury_form_add_subscriber_comment', '');
        update_option('emercury_form_select_list_subscriber_comment', '');
        $message_comment = '<strong>For correct operation, install checkbox and select the list!</strong>';
        $class_comment = 'error';
    
    } else if(!empty($checkbox_comment) || !empty($select_list_comment) ) {
        update_option('emercury_form_add_subscriber_comment', $checkbox_comment);
        update_option('emercury_form_select_list_subscriber_comment', $select_list_comment);
        $message_comment = 'Data updated successfully!';
        $class_comment = 'notice-success';
    }

    if (empty($checkbox_signup) || empty($select_list_signup) ) {
        
        update_option('emercury_form_add_subscriber_signup', '');
        update_option('emercury_form_select_list_subscriber_signup', '');
        $message_signup = '<strong>For correct operation, install checkbox and select the list!</strong>';
        $class_signup = 'error';
    
    } else if(!empty($checkbox_signup) || !empty($select_list_signup) ) {
        update_option('emercury_form_add_subscriber_signup', $checkbox_signup);
        update_option('emercury_form_select_list_subscriber_signup', $select_list_signup);
        $message_signup = 'Data updated successfully!';
        $class_signup = 'notice-success';
    }

    echo json_encode(array(
        'message_comment' => $message_comment ? $message_comment : '',
        'class_comment' => $class_comment ? $class_comment : '',
        'message_signup' => $message_signup ? $message_signup : '',
        'class_signup' => $class_signup ? $class_signup : ''
    ));

    wp_die();
}

add_action( 'hook_emercury_form_and_shortcodes', 'display_emercury_form_and_shortcodes', 10, 1 );
function display_emercury_form_and_shortcodes( $message ){

    ?>

    <div class="wrap">

        <?php if (!empty($message)) : ?>

        <div id="message" class="<?php echo $class; ?>">
            <p><?php echo $message; ?></p>
        </div>

        <?php endif; ?>

        <h2 id="title-update-emercury-form">Get / Update Emercury Forms </h2>
        <form id="update-emercury-form" method="POST">
            <input type="hidden" value="emercury_form_get_update" name="action">
            <p class="submit">
                <input class="button button-primary" type="submit" value="Get / Update">
            </p>
        </form>

        <h2 id="title-emercury-form-update-single" style="margin-bottom: 10px;">Shortcodes for Existing Emercury Forms </h2>
        <div>
            <?php echo get_shortcodes_existing_emercury_forms(); ?>
        </div>
    </div>

    <?php
}

function get_shortcodes_existing_emercury_forms() {
    
    $emercury_forms = new Emercury_WP_Integration();
    $emercury_forms_tbl = Emercury_WP_Integration::$table_emercury;
        
    $shortcodes_html = '<i>You have not ready to use shortcodes yet, please use <a href="admin.php?page=emercury_forms_settings">Settings</a> below to get shortcodes later.</i>';
        
    $forms = $emercury_forms->_wpdb->get_results( "SELECT form_id, name FROM $emercury_forms_tbl" );
        
    if (count($forms)) {
        
        $shortcodes_html = '<table>
                                <tr>
                                    <td><h3>Form Name</h3></td>
                                    <td><h3>Shortcode</h3></td>
                                    <td><h3>Action</h3></td>
                                </tr>';
            
        foreach ($forms as $form) {
    
            $shortcodes_html .= '<tr>
                                    <td style="padding-right: 50px; font-weight: bold;">'.$form->name.'</td>
                                    <td style="padding-right: 50px;">[emercury_forms id="'.$form->form_id.'"]</td>
                                    <td>
                                        <form class="emercury-form-update-single" method="POST">
                                            <input type="hidden" name="action" value="emercury_form_update_single">
                                            <input type="hidden" name="form_id" value="'.$form->form_id.'">
                                            <input type="hidden" name="emercury_forms_sec_id" value="'.get_option('emercury_forms_sec_id').'">
                                            <input class="button button-primary" type="submit" value="Update">
                                        </form>
                                    <td>
                                </tr>';
            
        }
        
        $shortcodes_html .= '</table>';    
    } 
        
    return $shortcodes_html;
}
